# Mapping Fact Sheets and Dictionary Items
### On this page
  * [Introduction](https://help.sap.com/docs/leanix/ea/mapping-fact-sheets-and-dictionary-items#introduction)
  * [Mapping Fact Sheets and Dictionary Items](https://help.sap.com/docs/leanix/ea/mapping-fact-sheets-and-dictionary-items#mapping-fact-sheets-and-dictionary-items)
  * [Choosing Source for Synchronization](https://help.sap.com/docs/leanix/ea/mapping-fact-sheets-and-dictionary-items#choosing-source-for-synchronization)
  * [Mapping Fact Sheets and Dictionary Items](https://help.sap.com/docs/leanix/ea/mapping-fact-sheets-and-dictionary-items#mapping-fact-sheets-and-dictionary-items-1)
  * [Syncing Associated Relations](https://help.sap.com/docs/leanix/ea/mapping-fact-sheets-and-dictionary-items#syncing-associated-relations)
  * [Choosing Sync Mode](https://help.sap.com/docs/leanix/ea/mapping-fact-sheets-and-dictionary-items#choosing-sync-mode)
  * [Filtering Fact Sheets](https://help.sap.com/docs/leanix/ea/mapping-fact-sheets-and-dictionary-items#filtering-fact-sheets)
  * [Activating and Deactivating the Mapping](https://help.sap.com/docs/leanix/ea/mapping-fact-sheets-and-dictionary-items#activating-and-deactivating-the-mapping)


View all
Learn how to map applications, business capabilities, organizations, and other fact sheets to dictionary items. Configure synchronization modes, map attributes of fact sheets and dictionary items, and manage value mappings.
